@@ -12,7 +12,7 @@ class Engine():
         self.interpreter = interpreter or ExecInterpreter()
 
     def process(self, script):
-        self.interpreter.interpret(self.context, script)
+        self.interpreter.interpret(script, self.context)
         return self.renderer.render(self.context)
 
     def processFile(self, pathIn, pathOut=None):
@@ -25,5 +25,9 @@ class Engine():
         filePathOut.type = result.type
         filePathOut.write(result.value)
 
-    def processFiles(self, pathRoot):
-        raise NotImplementedError()
+    def processFiles(self, pathRoot, recursive=False):
+        for filePathIn in FilePath.match(
+                root=pathRoot,
+                recursive=recursive,
+                filePattern='xvg$'):
+            self.processFile(filePathIn)
