@@ -1,2 +1,2 @@
-from .idealcontext import *
+from .context import *
 from .purecontext import *
