@@ -18,25 +18,25 @@ class Object(object):
         self.__dict__[key] = value
 
     def getFieldKeys(self):
-        return getFieldKeys(self)
+        return ClassReflection.getFieldKeys(self)
 
     def getFieldValues(self):
-        return getFieldValues(self)
+        return ClassReflection.getFieldValues(self)
 
     def getFields(self):
-        return getFields(self)
+        return ClassReflection.getFields(self)
 
     def getPublicFields(self):
-        return getPublicFields(self)
+        return ClassReflection.getPublicFields(self)
 
     def getPrivateFields(self):
-        return getPrivateFields(self)
+        return ClassReflection.getPrivateFields(self)
 
     def getMethods(self):
-        return getMethods(self)
+        return ClassReflection.getMethods(self)
 
     def getPublicMethods(self):
-        return getPublicMethods(self)
+        return ClassReflection.getPublicMethods(self)
 
     def getPrivateMethods(self):
-        return getPrivateMethods(self)
+        return ClassReflection.getPrivateMethods(self)
