@@ -1,3 +1,3 @@
 class Query():
     def __init__(self):
-        pass
+        raise NotImplementedError()
