@@ -4,7 +4,7 @@ from xvg.core import *
 class JSONRenderer():
 
     def render(self, context):
-        result = toJSON(context)
+        result = JSON.serialize(context)
         return FileData(
             value=result,
             type=JSONFileType(),
